==> Jifty-DBI-0.40.tar.gz: Jifty-DBI-0.40/t/testmodels.pl <==
package Sample::Employee;
use Jifty::DBI::Schema;
use Jifty::DBI::Record schema {

column dexterity => type is 'integer';
column name      => 
    type is 'varchar',
    is indexed;
column label     => type is 'varchar';
column type      => type is 'varchar';

};

sub schema_sqlite {
    return q{
    CREATE TABLE employees (
      id INTEGER PRIMARY KEY NOT NULL  ,
      dexterity integer   ,
      name varchar   ,
      label varchar   ,
      type varchar
    ) ;
    CREATE INDEX employees1 ON employees (name) ;
    };
}

sub schema_pg {
    return q{
    CREATE TABLE employees (
      id serial NOT NULL ,
      dexterity integer ,
      name varchar ,
      label varchar ,
      type varchar ,
      PRIMARY KEY (id)
    ) ;
    CREATE INDEX employees1 ON employees (name) ;
    };

}

package Sample::Address;
use Jifty::DBI::Schema;
use Jifty::DBI::Record schema {

column employee_id =>
  references Sample::Employee;

column name =>
  type is 'varchar',
  default is 'Frank';

column phone =>
  type is 'varchar';

column street =>
  type is 'varchar',
  since '0.2.4',
  till '0.2.8';

};

sub validate_name { 1 }

my $schema_version = undef;
sub schema_version {
    my $class = shift;
    my $new_schema_version = shift;
    $schema_version = $new_schema_version if defined $new_schema_version;
    return $schema_version;
}

sub schema_sqlite {
    return q{
    CREATE TABLE addresses (
     id INTEGER PRIMARY KEY NOT NULL  ,
     employee_id integer   ,
     name varchar  DEFAULT 'Frank' ,
     phone varchar
    ) ;
    }
}

sub schema_sqlite_024 {
    return q{
    CREATE TABLE addresses (
     id INTEGER PRIMARY KEY NOT NULL  ,
     employee_id integer   ,
     name varchar  DEFAULT 'Frank' ,
     phone varchar ,
     street varchar
    ) ;
    }
}

sub schema_pg {
    return q{
    CREATE TABLE addresses ( 
      id serial NOT NULL , 
      employee_id integer  ,
      name varchar DEFAULT 'Frank' ,
      phone varchar ,
      PRIMARY KEY (id)
    ) ;
    };
}

sub schema_pg_024 {
    return q{
    CREATE TABLE addresses ( 
      id serial NOT NULL , 
      employee_id integer  ,
      name varchar DEFAULT 'Frank' ,
      phone varchar ,
      street varchar ,
      PRIMARY KEY (id)
    ) ;
    };
}

1;

==> Jifty-DBI-0.43.tar.gz: Jifty-DBI-0.43/t/testmodels.pl <==
package Sample::Employee;
use Jifty::DBI::Schema;
use Jifty::DBI::Record schema {

column dexterity => type is 'integer';
column name      => 
    type is 'varchar',
    is indexed;
column label     => type is 'varchar';
column type      => type is 'varchar';

};

sub schema_sqlite {
    return q{
    CREATE TABLE employees (
      id INTEGER PRIMARY KEY AUTOINCREMENT NOT NULL  ,
      dexterity integer   ,
      name varchar   ,
      label varchar   ,
      type varchar
    ) ;
    CREATE INDEX employees1 ON employees (name) ;
    };
}

sub schema_pg {
    return q{
    CREATE TABLE employees (
      id serial NOT NULL ,
      dexterity integer ,
      name varchar ,
      label varchar ,
      type varchar ,
      PRIMARY KEY (id)
    ) ;
    CREATE INDEX employees1 ON employees (name) ;
    };

}

package Sample::Address;
use Jifty::DBI::Schema;
use Jifty::DBI::Record schema {

column employee_id =>
  references Sample::Employee;

column name =>
  type is 'varchar',
  default is 'Frank';

column phone =>
  type is 'varchar';

column street =>
  type is 'varchar',
  since '0.2.4',
  till '0.2.8';

};

sub validate_name { 1 }

my $schema_version = undef;
sub schema_version {
    my $class = shift;
    my $new_schema_version = shift;
    $schema_version = $new_schema_version if defined $new_schema_version;
    return $schema_version;
}

sub schema_sqlite {
    return q{
    CREATE TABLE addresses (
     id INTEGER PRIMARY KEY AUTOINCREMENT NOT NULL  ,
     employee_id integer   ,
     name varchar  DEFAULT 'Frank' ,
     phone varchar
    ) ;
    }
}

sub schema_sqlite_024 {
    return q{
    CREATE TABLE addresses (
     id INTEGER PRIMARY KEY AUTOINCREMENT NOT NULL  ,
     employee_id integer   ,
     name varchar  DEFAULT 'Frank' ,
     phone varchar ,
     street varchar
    ) ;
    }
}

sub schema_pg {
    return q{
    CREATE TABLE addresses ( 
      id serial NOT NULL , 
      employee_id integer  ,
      name varchar DEFAULT 'Frank' ,
      phone varchar ,
      PRIMARY KEY (id)
    ) ;
    };
}

sub schema_pg_024 {
    return q{
    CREATE TABLE addresses ( 
      id serial NOT NULL , 
      employee_id integer  ,
      name varchar DEFAULT 'Frank' ,
      phone varchar ,
      street varchar ,
      PRIMARY KEY (id)
    ) ;
    };
}

1;
